==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ColorPreferences/ts/ColorPreferences_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>ColorPreferences</name>
    <message>
        <location filename="../ColorPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Plocha Grafiky</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Colors</source>
        <translation>Farby</translation>
    </message>
</context>
<context>
    <name>GraphicsViewColors</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Graphics View</source>
        <translation>Pohľad grafiky</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background:</source>
        <translation>Pozadie:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Cursor</source>
        <translation>Kurzor</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Crosshairs:</source>
        <translation>Krížik:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Inactive crosshairs:</source>
        <translation>Neaktívny krížik:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Origin</source>
        <translation>Nulový bod</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Origin:</source>
        <translation>Nulový bod:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Relative zero:</source>
        <translation>Relatívny nulový bod:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Grid</source>
        <translation>Sieť/Mriežka</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Grid:</source>
        <translation>Sieť:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Meta grid:</source>
        <translation>Mriežka:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection</source>
        <translation>Výber prvkov</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Primary selection color:</source>
        <translation>Farba hlavného výberu prvkov:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Use secondary selection color</source>
        <translation>Použiť sekundárnu farbu pre výber</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Secondary selection color:</source>
        <translation>Farba sekundárneho výberu:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Draggable reference points:</source>
        <translation>Referenčné body:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Secondary reference points:</source>
        <translation>Druhé body:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection box border:</source>
        <translation>Okraj boxu výberu:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Selection box fill:</source>
        <translation>Výplň boxu výberu zľava doprava:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Cross-selection box fill:</source>
        <translation>Výplň boxu výberu sprava doľava:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Snap Tools</source>
        <translation>Nástroje prichytávania</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Snap label:</source>
        <translation>Text prichytávania:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Info Tools</source>
        <translation>Informačné Nástroje</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Measurements and labels:</source>
        <translation>Text merania a všetko okolo toho:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Drawing Tools</source>
        <translation>Nástroje kreslenia</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Auxiliary shapes:</source>
        <translation>Pomocné tvary:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Zoom Tools</source>
        <translation>Nástroje zväčšenia</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Zoom box border:</source>
        <translation>Okraj boxu zväčšenia:</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/AppPreferences/GraphicsViewPreferences/ColorPreferences/ts/ColorPreferences_sk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>ColorPreferences</name>
    <message>
        <location filename="../ColorPreferences.js" line="+24"/>
        <source>Graphics View</source>
        <translation>Plocha Grafiky</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Colors</source>
        <translation>Farby</translation>
    </message>
</context>
<context>
    <name>GraphicsViewColors</name>
    <message>
        <location filename="../PreferencesPage.ui" line="+32"/>
        <source>Graphics View</source>
        <translation>Pohľad grafiky</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Background:</source>
        <translation>Pozadie:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Cursor</source>
        <translation>Kurzor</translation>
    </message>
    <message>
        <location line="+18"/>
        <source>Crosshairs:</source>
        <translation>Krížik:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Inactive crosshairs:</source>
        <translation>Neaktívny krížik:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Origin</source>
        <translation>Nulový bod</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Origin:</source>
        <translation>Nulový bod:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Relative zero:</source>
        <translation>Relatívny nulový bod:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Grid</source>
        <translation>Sieť/Mriežka</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Grid:</source>
        <translation>Sieť:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Meta grid:</source>
        <translation>Mriežka:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection</source>
        <translation>Výber prvkov</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Primary selection color:</source>
        <translation>Farba hlavného výberu prvkov:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Use secondary selection color</source>
        <translation>Použiť sekundárnu farbu pre výber</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Secondary selection color:</source>
        <translation>Farba sekundárneho výberu:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Draggable reference points:</source>
        <translation>Referenčné body:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Secondary reference points:</source>
        <translation>Druhé body:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Selection box border:</source>
        <translation>Okraj boxu výberu:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Selection box fill:</source>
        <translation>Výplň boxu výberu zľava doprava:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Cross-selection box fill:</source>
        <translation>Výplň boxu výberu sprava doľava:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Start points:</source>
        <translation>Začiatočné body:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>End points:</source>
        <translation>Koncové body:</translation>
    </message>
    <message>
        <location line="+50"/>
        <source>Snap Tools</source>
        <translation>Nástroje prichytávania</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Snap label:</source>
        <translation>Text prichytávania:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Info Tools</source>
        <translation>Informačné Nástroje</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Measurements and labels:</source>
        <translation>Text merania a všetko okolo toho:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Drawing Tools</source>
        <translation>Nástroje kreslenia</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Auxiliary shapes:</source>
        <translation>Pomocné tvary:</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Zoom Tools</source>
        <translation>Nástroje zväčšenia</translation>
    </message>
    <message>
        <location line="+12"/>
        <source>Zoom box border:</source>
        <translation>Okraj boxu zväčšenia:</translation>
    </message>
</context>
</TS>
